[![Join the chat at https://gitter.im/Deltares/hydrolib](https://badges.gitter.im/Deltares/hydrolib.svg)](https://gitter.im/Deltares/hydrolib?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![ci](https://github.com/Deltares/HYDROLIB-core/actions/workflows/ci.yml/badge.svg)](https://github.com/Deltares/HYDROLIB-core/actions/workflows/ci.yml)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=Deltares_HYDROLIB-core&metric=alert_status)](https://sonarcloud.io/dashboard?id=Deltares_HYDROLIB-core)


# HYDROLIB-core
HYDROLIB-core is the core library of Python wrappers around the D-HYDRO model files (input and output) and model engines (kernel libraries).
It can serve as the basis for various pre- and postprocessing tools for a modelling workflow of hydrodynamic simulations.

<div align="center">
<img src="docs/images/HYDROLIB_logo_paths.svg" width="50%">
</div>

## More information
Much more information is available from the dedicated package website.

Some quickstarts:
* First users: [Installation](https://deltares.github.io/HYDROLIB-core/latest/guides/setup/) and [Tutorials](https://deltares.github.io/HYDROLIB-core/latest/tutorials/tutorials).
* Developers: [List of supported functionalities](https://deltares.github.io/HYDROLIB-core/latest/topics/dhydro_support/),
  [API reference](https://deltares.github.io/HYDROLIB-core/latest/reference/api/), and
  [How to contribute](https://deltares.github.io/HYDROLIB-core/latest/guides/contributing/).
* Releases: [hydrolib-core on PyPI](https://pypi.org/project/hydrolib-core/), [ChangeLog](https://deltares.github.io/HYDROLIB-core/latest/changelog/).
* Known issues and requested features: via [GitHub issues](https://github.com/Deltares/HYDROLIB-core/issues).
